==> event_tracker-0.0.1.tar.gz: lib/LemniskFlutterTrack.dart <==
import 'dart:convert';
import 'dart:math';

import 'package:event_tracker/platform_device_id.dart';
import 'package:flutter/services.dart';
import 'package:http/http.dart' as http;

import 'model/TrackBulider.dart';

/// Provides device id information.
class LemniskFlutterTrack {
  static String? trackPayLoad;
  static void track(String activityName, TrackBulider properties, OtherID otherid) async {
    try {
      //after taking paramters from user....
      //just received nd it on server
      String? deviceId;
      String? deviceType;
      String? deviceManufacture;
      String? deviceModel;
      String? androidID;
      String? versionName;
      String? appName;
      String? appVersion;
      String? appBuild;
      String? googleAdvertisingID;

      String? networkIP;
      String? appScreenHeightWidth;
      String? appScreenHeightHeight;
      String? appDataReceivedAt;
      String? appDataSenddAt;

      String? writekey;
      String? appOriginalTimetemp;
      String? appTimestemp;
      dynamic? googleAdvertisingBool;

      try {
        deviceId = await PlatformDeviceId.getDeviceId;
        deviceType = await PlatformDeviceId.getPlatFormDeviceType;
        deviceModel = await PlatformDeviceId.getDeviceModel;
        deviceManufacture = await PlatformDeviceId.getManufactureModel;
        versionName = await PlatformDeviceId.getOSVersion;
        appName = await PlatformDeviceId.getAppName;
        appVersion = await PlatformDeviceId.getAppVersion;
        appBuild = await PlatformDeviceId.getBuildNumber;
        googleAdvertisingID = await PlatformDeviceId.getGoogleadvertisingID;
        googleAdvertisingBool = await PlatformDeviceId.getGoogleadvertisingIDBoolValue;
        networkIP = await PlatformDeviceId.getNetworkIP;
        writekey = await PlatformDeviceId.getWriteKey;

        appScreenHeightHeight = await PlatformDeviceId.getScreenHeight;
        appScreenHeightWidth = await PlatformDeviceId.getScreenWidth;

        appDataReceivedAt = await PlatformDeviceId.getReceivedAt;
        appDataSenddAt = await PlatformDeviceId.getSendAt;

        appOriginalTimetemp = await PlatformDeviceId.getOriginalTimetemp;
        appTimestemp = await PlatformDeviceId.getTimestemp;
      } on PlatformException {
        deviceId = 'Failed to get deviceId.';
      }

      //after received all data create josn payload...now we can hit to server

      //context nested map prepare
      Map<dynamic, dynamic> lib = {
        "library": {
          "name": "Flutter SDK",
          "version": "0.01",
        },
        "app": {
          "name": appName,
          "version": appVersion,
          "build": appBuild,
        },
        "device": {
          "id": androidID,
          "advertisingId": googleAdvertisingID,
          "adTrackingEnabled": googleAdvertisingBool,
          "manufacturer": deviceManufacture,
          "model": deviceModel,
          "type": deviceType,
          "token": "ff15bc0c20c4aa6cd50854ff165fd265c838e5405bfeb9571066395b8c9da449",
        },
        "screen": {
          "width": appScreenHeightWidth,
          "height": appScreenHeightHeight,
          "density": 2,
        },
        "userAgent": {
          "osType": deviceType,
          "osVersion": versionName,
        },
        "ip": networkIP
      };

      Map map = {
        "id": getRandomString(20),
        "userId": "6791c47a-0178-47bc-8711-86a2c67b2255",
        "otherIds": otherid,
        "event": activityName,
        "messageId": "ajs-f8ca1e4de5024d9430b3928bd8ac6b96",
        "properties": properties,
        "receivedAt": appDataReceivedAt,
        "sentAt": appDataSenddAt,
        "timestamp": appTimestemp,
        "type": "track",
        "originalTimestamp": appOriginalTimetemp,
        "writeKey": writekey,
      };

      map.addAll({"context": lib});
      print(JsonEncoder().convert(map));

      //we can hit on server....
      String url = "https://tpl.lemnisk.co/analyze/analyze.php";
      print('trackevent' + url);
      Uri uri = Uri.parse(url);
      trackPayLoad = JsonEncoder().convert(map);
      var response = await http.post(uri, body: trackPayLoad);
      if (response.statusCode == 200) {
        final String responseString = response.body;
        print('event track success=====   $responseString');
      } else {
        final String responseString = response.body;
        print('event track falied=====   $responseString');
      }
    } on PlatformException {
      print('someexception occoured');
    }
  }
}

const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
Random _rnd = Random();
String getRandomString(int length) => String.fromCharCodes(Iterable.generate(length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));

==> event_tracker-0.0.2.tar.gz: lib/LemniskFlutterTrack.dart <==
import 'dart:convert';
import 'dart:math';

import 'package:event_tracker/platform_device_id.dart';
import 'package:flutter/services.dart';
import 'package:http/http.dart' as http;

import 'model/TrackBulider.dart';

/// Provides device id information.
class LemniskFlutterTrack {
  static String? _trackPayLoad;
  static void track(String trackName, TrackBulider properties, OtherID otherid) async {
    try {
      //after taking paramters from user.... //just received nd it on server

      //getting device details
      String? deviceId;
      String? deviceType;
      String? deviceManufacture;
      String? deviceModel;
      String? versionName;
      //getting app information
      String? appName;
      String? appVersion;
      String? appBuild;
      //google adertising id its bool value
      String? googleAdvertisingID;
      dynamic? googleAdvertisingBool;
      //network ip
      String? networkIP;
      //phone height width
      String? appScreenHeightWidth;
      String? appScreenHeightHeight;
      //json reseived send timestemp
      String? appDataReceivedAt;
      String? appDataSenddAt;
      String? appOriginalTimetemp;
      String? appTimestemp;
      //write key
      String? writekey;

      try {
        deviceId = await PlatformDeviceId.getDeviceId;
        deviceType = await PlatformDeviceId.getPlatFormDeviceType;
        deviceModel = await PlatformDeviceId.getDeviceModel;
        deviceManufacture = await PlatformDeviceId.getManufactureModel;
        versionName = await PlatformDeviceId.getOSVersion;
        appName = await PlatformDeviceId.getAppName;
        appVersion = await PlatformDeviceId.getAppVersion;
        appBuild = await PlatformDeviceId.getBuildNumber;
        googleAdvertisingID = await PlatformDeviceId.getGoogleadvertisingID;
        googleAdvertisingBool = await PlatformDeviceId.getGoogleadvertisingIDBoolValue;
        networkIP = await PlatformDeviceId.getNetworkIP;
        writekey = await PlatformDeviceId.getWriteKey;

        appScreenHeightHeight = await PlatformDeviceId.getScreenHeight;
        appScreenHeightWidth = await PlatformDeviceId.getScreenWidth;

        appDataReceivedAt = await PlatformDeviceId.getReceivedAt;
        appDataSenddAt = await PlatformDeviceId.getSendAt;

        appOriginalTimetemp = await PlatformDeviceId.getOriginalTimetemp;
        appTimestemp = await PlatformDeviceId.getTimestemp;
      } on PlatformException {
        deviceId = 'Failed to get deviceId.';
      }

      //after received all data create josn payload...now we can hit the server  //context nested map prepare

      Map<dynamic, dynamic> lib = {
        "library": {
          "name": "Flutter SDK",
          "version": "0.01",
        },
        "app": {
          "name": appName,
          "version": appVersion,
          "build": appBuild,
        },
        "device": {
          "id": deviceId,
          "advertisingId": googleAdvertisingID,
          "adTrackingEnabled": googleAdvertisingBool,
          "manufacturer": deviceManufacture,
          "model": deviceModel,
          "type": deviceType,
          "token": "ff15bc0c20c4aa6cd50854ff165fd265c838e5405bfeb9571066395b8c9da449",
        },
        "screen": {
          "width": appScreenHeightWidth,
          "height": appScreenHeightHeight,
          "density": 2,
        },
        "userAgent": {
          "osType": deviceType,
          "osVersion": versionName,
        },
        "ip": networkIP
      };

      Map map = {
        "id": getRandomString(20),
        "userId": "6791c47a-0178-47bc-8711-86a2c67b2255",
        "otherIds": otherid,
        "event": trackName,
        "messageId": "ajs-f8ca1e4de5024d9430b3928bd8ac6b96",
        "properties": properties,
        "receivedAt": appDataReceivedAt,
        "sentAt": appDataSenddAt,
        "timestamp": appTimestemp,
        "type": "track",
        "originalTimestamp": appOriginalTimetemp,
        "writeKey": writekey,
      };
      map.addAll({"context": lib});
      //print(JsonEncoder().convert(map));

      //we can hit on server....
      String url = "https://tpl.lemnisk.co/analyze/analyze.php";
      print('trackevent' + url);
      Uri uri = Uri.parse(url);
      _trackPayLoad = JsonEncoder().convert(map);
      var response = await http.post(uri, body: _trackPayLoad);
      if (response.statusCode == 200) {
        final String responseString = response.body;
        print('event track success=====   $responseString');
      } else {
        final String responseString = response.body;
        print('event track falied=====   $responseString');
      }
    } on PlatformException {
      print('someexception occoured');
    }
  }
}

const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
Random _rnd = Random();
String getRandomString(int length) => String.fromCharCodes(Iterable.generate(length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));
